/******************************************************************************
 *                                                                            *
 * File:   textedit.h         Version: 1.00            Date: 1996-12-19       *
 *                                                                            *
 * Copyright (C) 1996 by kostis@acm.org (Kosta Kostis)                        *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * History:                                                                   *
 *     1996-12-19: KK V1.00                                                   *
 *        - initial coding                                                    *
 *                                                                            *
 *****************************************************************************/

/******************************************************************************

	Handy Data Types

 *****************************************************************************/

#ifndef	HANDY_DATATYPES

	#define	HANDY_DATATYPES
	typedef	unsigned char	uchar ;
	typedef	unsigned long	ulong ;

#endif

/******************************************************************************

	Library Information

 *****************************************************************************/

#define	TEXT_LIBNAM	"TextEdit"
#define	TEXT_LIBVER	"V1.00 (1996-12-19)"

/******************************************************************************

	TextLine and TextFile Data Structure

 *****************************************************************************/

typedef	struct	TextLine
{
	uchar			*L ;		/* line buffer */
	struct	TextLine	*N ;		/* ptr to next element */
	struct	TextLine	*P ;		/* ptr to previous element */
} TextLine ;

typedef	struct	TextFile
{
	TextLine		*Top ;		/* start of text */
	TextLine		*CurTop ;	/* current home position */
	TextLine		*CurPos ;	/* current position */
} TextFile ;

#ifdef	TEXT_MAKELIB
	#include "textlib.h"
#endif

/******************************************************************************

	TextCore Functions

 *****************************************************************************/

extern	void		TextFree (TextFile *CurText) ;

/******************************************************************************

	TextEdit Functions (public)

 *****************************************************************************/

extern	int		TextEdit (char *FileName) ;

/******************************************************************************

	TextEnv Function

 *****************************************************************************/

extern	int		TextEnvParse (uchar *Buffer) ;

/******************************************************************************

	TextFind Functions

 *****************************************************************************/

extern	int		TextFind (TextFile *CurText, uchar *Pattern) ;
extern	int		TextFindValue
(
				TextFile	*CurText,
				uchar		*Section,
				uchar		*Pattern
) ;
extern	int		TextFindSection (TextFile *CurText, uchar *Section) ;
extern	int		TextReplace
(
				TextFile	*CurText,
				uchar		*Search,
				uchar		*Replace
) ;

/******************************************************************************

	TextIO Functions

 *****************************************************************************/

extern	int		TextRead (TextFile *CurText, char *FileName) ;
extern	int		TextSave (TextFile *CurText, char *FileName) ;

/******************************************************************************

	TextModi Functions

 *****************************************************************************/

extern	int		TextAdd (TextFile *CurText, uchar *NewLine) ;
extern	int		TextIns (TextFile *CurText, uchar *NewLine) ;
extern	int		TextDel (TextFile *CurText) ;
extern	uchar		*TextGetLine (TextFile *CurText) ;
extern	int		TextSetLine (TextFile *CurText, uchar *Value) ;
extern	uchar		*TextGetValue (TextFile *CurText, int delim) ;
extern	int		TextSetValue
(
				TextFile	*CurText,
				int		delim,
				uchar		*Value
) ;

/******************************************************************************

	TextPos Functions

 *****************************************************************************/

extern	int		TextPosDn (TextFile *CurText) ;
extern	int		TextPosUp (TextFile *CurText) ;
extern	int		TextPosEnd (TextFile *CurText) ;
extern	int		TextPosHome (TextFile *CurText) ;
extern	int		TextPos (TextFile *CurText, ulong Index) ;
extern	ulong		TextLines (TextFile *CurText) ;
extern	ulong		TextPosLine (TextFile *CurText) ;

/******************************************************************************

	Function Return Values

 *****************************************************************************/

#define	TEXT_OK			100
#define	TEXT_NOTFOUND		101

#define	TEXT_NULL		110
#define	TEXT_MEMORY		111

#define	TEXT_OPEN		120
#define	TEXT_READ		121
#define	TEXT_LONG		122
#define	TEXT_EOF		123

#define	TEXT_CREATE		130
#define	TEXT_WRITE		131

#define	TEXT_SYNTAX		140

#define	TEXT_ABORT		255
